.. sugar.py documentation master file

.. include:: ../README.rst

Guide
=====

.. toctree::
    :maxdepth: 3

    installation
    api


Project Info
============

.. toctree::
    :maxdepth: 1

    license
    versioning
    changelog
    authors
    contributing



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

